@@ -19,8 +19,8 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
 """
-from mypy_boto3_secretsmanager.client import SecretsManagerClient
-from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
+from .client import SecretsManagerClient
+from .paginator import ListSecretsPaginator
 
 Client = SecretsManagerClient
 
