@@ -82,7 +82,7 @@ class Exceptions:
 
 class SecretsManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
     """
 
@@ -98,7 +98,7 @@ class SecretsManagerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#can_paginate)
         """
 
@@ -107,7 +107,7 @@ class SecretsManagerClient(BaseClient):
         Turns off automatic rotation, and if a rotation is currently in progress,
         cancels the rotation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#cancel_rotate_secret)
         """
 
@@ -127,7 +127,7 @@ class SecretsManagerClient(BaseClient):
         """
         Creates a new secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#create_secret)
         """
 
@@ -135,7 +135,7 @@ class SecretsManagerClient(BaseClient):
         """
         Deletes the resource-based permission policy attached to the secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_resource_policy)
         """
 
@@ -149,7 +149,7 @@ class SecretsManagerClient(BaseClient):
         """
         Deletes a secret and all of its versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_secret)
         """
 
@@ -157,7 +157,7 @@ class SecretsManagerClient(BaseClient):
         """
         Retrieves the details of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#describe_secret)
         """
 
@@ -171,7 +171,7 @@ class SecretsManagerClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#generate_presigned_url)
         """
 
@@ -190,7 +190,7 @@ class SecretsManagerClient(BaseClient):
         """
         Generates a random password.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_random_password)
         """
 
@@ -199,7 +199,7 @@ class SecretsManagerClient(BaseClient):
         Retrieves the JSON text of the resource-based policy document attached to the
         secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_resource_policy)
         """
 
@@ -210,7 +210,7 @@ class SecretsManagerClient(BaseClient):
         Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`
         from the specified version of a secret, whichever contains content.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_secret_value)
         """
 
@@ -225,7 +225,7 @@ class SecretsManagerClient(BaseClient):
         """
         Lists the versions for a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secret_version_ids)
         """
 
@@ -238,10 +238,9 @@ class SecretsManagerClient(BaseClient):
         SortOrder: SortOrderTypeType = ...
     ) -> ListSecretsResponseTypeDef:
         """
-        Lists the secrets that are stored by Secrets Manager in the Amazon Web Services
-        account.
+        .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secrets)
         """
 
@@ -251,7 +250,7 @@ class SecretsManagerClient(BaseClient):
         """
         Attaches a resource-based permission policy to a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_resource_policy)
         """
 
@@ -268,7 +267,7 @@ class SecretsManagerClient(BaseClient):
         Creates a new version with a new encrypted secret value and attaches it to the
         secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_secret_value)
         """
 
@@ -279,7 +278,7 @@ class SecretsManagerClient(BaseClient):
         For a secret that is replicated to other Regions, deletes the secret replicas
         from the Regions you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#remove_regions_from_replication)
         """
 
@@ -293,7 +292,7 @@ class SecretsManagerClient(BaseClient):
         """
         Replicates the secret to a new Regions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#replicate_secret_to_regions)
         """
 
@@ -302,7 +301,7 @@ class SecretsManagerClient(BaseClient):
         Cancels the scheduled deletion of a secret by removing the `DeletedDate` time
         stamp.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#restore_secret)
         """
 
@@ -312,12 +311,13 @@ class SecretsManagerClient(BaseClient):
         SecretId: str,
         ClientRequestToken: str = ...,
         RotationLambdaARN: str = ...,
-        RotationRules: "RotationRulesTypeTypeDef" = ...
+        RotationRules: "RotationRulesTypeTypeDef" = ...,
+        RotateImmediately: bool = ...
     ) -> RotateSecretResponseTypeDef:
         """
         Configures and starts the asynchronous process of rotating the secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#rotate_secret)
         """
 
@@ -328,7 +328,7 @@ class SecretsManagerClient(BaseClient):
         Removes the link between the replica secret and the primary secret and promotes
         the replica to a primary secret in the replica Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#stop_replication_to_replica)
         """
 
@@ -336,7 +336,7 @@ class SecretsManagerClient(BaseClient):
         """
         Attaches tags to a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#tag_resource)
         """
 
@@ -344,7 +344,7 @@ class SecretsManagerClient(BaseClient):
         """
         Removes specific tags from a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#untag_resource)
         """
 
@@ -361,7 +361,7 @@ class SecretsManagerClient(BaseClient):
         """
         Modifies the details of a secret, including metadata and the secret value.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret)
         """
 
@@ -376,7 +376,7 @@ class SecretsManagerClient(BaseClient):
         """
         Modifies the staging labels attached to a version of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret_version_stage)
         """
 
@@ -387,12 +387,12 @@ class SecretsManagerClient(BaseClient):
         Validates that a resource policy does not grant a wide range of principals
         access to your secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.24/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
